@@ -10,8 +10,8 @@ package plenigo::CustomersManager;
 
  # Prepare configuration
 
- my $activate_testing = 0;
- my $configuration = plenigo::Configuration->new(company_id => 'YOUR_COMPANY_ID, secret => 'YOUR_SECRET', staging => $activate_testing);
+ my $use_stage = 0; # set if stage system should be used
+ my $configuration = plenigo::Configuration->new(access_token => 'ACCESS_TOKEN', use_stage => $use_stage);
 
  # Instantiate customers manager
 
@@ -19,7 +19,7 @@ package plenigo::CustomersManager;
 
  # Register a new external customer
 
- my %customer_details = $customers_manager->registerCustomer('newuser@example.com', 'DE', '123456789', 'MALE', 'Mike', 'Miller', 0, 0);
+ my %customer_details = $customers_manager->registerCustomer('newuser@example.com', 'DE', '123456789', 'MR', 'Mike', 'Miller');
 
  # Change email address of an exiting customer
 
@@ -36,34 +36,34 @@ use Carp qw(confess);
 use plenigo::Ex;
 use plenigo::RestClient;
 
-our $VERSION = '2.0006';
+our $VERSION = '3.0000';
 
 has configuration => (
     is       => 'ro',
     required => 1
 );
 
-=head2 registerCustomer($email, $language, $external_customer_id, $salutation, $first_name, $surname, $with_password_reset, $fail_by_existing_email)
+=head2 registerCustomer($email, $language, $customer_id, $salutation, $first_name, $last_name)
 
 Register a new customer in the plenigo system.
 
 =cut
 
 sub registerCustomer {
-    my ($self, $email, $language, $external_customer_id, $salutation, $first_name, $surname, $with_password_reset, $fail_by_existing_email) = @_;
-    $with_password_reset //= 0;
-    $fail_by_existing_email //= 0;
+    my ($self, $email, $language, $customer_id, $salutation, $first_name, $last_name) = @_;
 
     my $rest_client = plenigo::RestClient->new(configuration => $self->configuration);
-    my %result = $rest_client->post('externalUser/register', {}, (
-        email               => $email,
-        language            => $language,
-        externalUserId      => $external_customer_id,
-        gender              => $salutation,
-        firstName           => $first_name,
-        surname             => $surname,
-        withPasswordReset   => $with_password_reset,
-        failByExistingEmail => $fail_by_existing_email
+    my %result = $rest_client->post('customers', {}, (
+        customerId => $customer_id,
+        email      => $email,
+        language   => $language,
+        gender     => $salutation,
+        addresses  => (
+            "type"      => "INVOICE",
+            "preferred" => 1,
+            firstName   => $first_name,
+            lastName    => $last_name,
+        )
     ));
     if ($result{'response_code'} == 409) {
         plenigo::Ex->throw({ code => 409, message => 'A customer with the given email already exists. If you want to avoid this error, set the fail_by_existing_email flag to false.' });
@@ -86,7 +86,7 @@ sub editCustomer {
     my ($self, $customer_id, $email) = @_;
 
     my $rest_client = plenigo::RestClient->new(configuration => $self->configuration);
-    my %result = $rest_client->put('externalUser/' . $customer_id . '/changeEmail', { useExternalCustomerId => $self->configuration->use_external_customer_id }, (email => $email));
+    my %result = $rest_client->put('customers/' . $customer_id, (email => $email));
     if ($result{'response_code'} == 404) {
         plenigo::Ex->throw({ code => 404, message => 'There is no customer for the customer id passed.' });
     }
