@@ -10,8 +10,8 @@ package plenigo::PurchasesManager;
 
  # Prepare configuration
 
- my $activate_testing = 0;
- my $configuration = plenigo::Configuration->new(company_id => 'YOUR_COMPANY_ID, secret => 'YOUR_SECRET', staging => $activate_testing);
+ my $use_stage = 0; # set if stage system should be used
+ my $configuration = plenigo::Configuration->new(access_token => 'ACCESS_TOKEN', use_stage => $use_stage);
 
  # Instantiate purchases manager
 
@@ -32,7 +32,7 @@ use Carp qw(confess);
 use plenigo::Ex;
 use plenigo::RestClient;
 
-our $VERSION = '2.0006';
+our $VERSION = '3.0000';
 
 has configuration => (
     is       => 'ro',
@@ -49,7 +49,7 @@ sub getCustomerSubscriptions {
     my ($self, $customer_id) = @_;
 
     my $rest_client = plenigo::RestClient->new(configuration => $self->configuration);
-    my %result = $rest_client->get('user/' . $customer_id . "/subscriptions", {useExternalCustomerId => $self->configuration->use_external_customer_id});
+    my %result = $rest_client->get('customers/' . $customer_id . "/subscriptions");
 
     if ($result{'response_code'} == 404) {
         plenigo::Ex->throw({ code => 409, message => 'No customer can be found for the given customer id.' });
